[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/git-branch#_name)
    * [SYNOPSIS](https://git-scm.com/docs/git-branch#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/git-branch#_description)
    * [OPTIONS](https://git-scm.com/docs/git-branch#_options)
    * [CONFIGURATION](https://git-scm.com/docs/git-branch#_configuration)
    * [EXAMPLES](https://git-scm.com/docs/git-branch#_examples)
    * [NOTES](https://git-scm.com/docs/git-branch#_notes)
    * [SEE ALSO](https://git-scm.com/docs/git-branch#_see_also)
    * [GIT](https://git-scm.com/docs/git-branch#_git)


[ English ▾](https://git-scm.com/docs/git-branch)
Localized versions of **git-branch** manual
  1. [English ](https://git-scm.com/docs/git-branch)
  2. [Français ](https://git-scm.com/docs/git-branch/fr)
  3. [Português (Brasil) ](https://git-scm.com/docs/git-branch/pt_BR)
  4. [Русский ](https://git-scm.com/docs/git-branch/ru)
  5. [Svenska ](https://git-scm.com/docs/git-branch/sv)
  6. [українська мова ](https://git-scm.com/docs/git-branch/uk)
  7. [简体中文 ](https://git-scm.com/docs/git-branch/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git-branch)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/git-branch) git-branch last updated in 2.51.0
Changes in the **git-branch** manual
  1. 2.51.1 → 2.53.0 no changes
  2. [2.51.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-08-18_ ](https://git-scm.com/docs/git-branch/2.51.0)
  3. 2.50.1 no changes
  4. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/git-branch/2.50.0)
  5. 2.44.1 → 2.49.1 no changes
  6. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git-branch/2.44.0)
  7. 2.43.1 → 2.43.7 no changes
  8. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git-branch/2.43.0)
  9. 2.41.1 → 2.42.4 no changes
  10. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git-branch/2.41.0)
  11. 2.40.1 → 2.40.4 no changes
  12. [2.40.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-03-12_ ](https://git-scm.com/docs/git-branch/2.40.0)
  13. 2.39.4 → 2.39.5 no changes
  14. [2.39.3 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-04-17_ ](https://git-scm.com/docs/git-branch/2.39.3)
  15. 2.38.1 → 2.39.2 no changes
  16. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git-branch/2.38.0)
  17. 2.37.1 → 2.37.7 no changes
  18. [2.37.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-06-27_ ](https://git-scm.com/docs/git-branch/2.37.0)
  19. 2.36.1 → 2.36.6 no changes
  20. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git-branch/2.36.0)
  21. 2.35.1 → 2.35.8 no changes
  22. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git-branch/2.35.0)
  23. 2.34.1 → 2.34.8 no changes
  24. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git-branch/2.34.0)
  25. 2.33.2 → 2.33.8 no changes
  26. [2.33.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-10-12_ ](https://git-scm.com/docs/git-branch/2.33.1)
  27. 2.31.1 → 2.33.0 no changes
  28. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git-branch/2.31.0)
  29. 2.30.1 → 2.30.9 no changes
  30. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/git-branch/2.30.0)
  31. 2.29.1 → 2.29.3 no changes
  32. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git-branch/2.29.0)
  33. 2.28.1 no changes
  34. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git-branch/2.28.0)
  35. 2.23.1 → 2.27.1 no changes
  36. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git-branch/2.23.0)
  37. 2.22.2 → 2.22.5 no changes
  38. [2.22.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-11_ ](https://git-scm.com/docs/git-branch/2.22.1)
  39. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git-branch/2.22.0)
  40. 2.21.1 → 2.21.4 no changes
  41. [2.21.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-02-24_ ](https://git-scm.com/docs/git-branch/2.21.0)
  42. 2.20.1 → 2.20.5 no changes
  43. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git-branch/2.20.0)
  44. 2.19.1 → 2.19.6 no changes
  45. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git-branch/2.19.0)
  46. 2.18.1 → 2.18.5 no changes
  47. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git-branch/2.18.0)
  48. 2.17.0 → 2.17.6 no changes
  49. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git-branch/2.16.6)
  50. [2.15.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git-branch/2.15.4)
  51. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git-branch/2.14.6)
  52. [2.13.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-05-22_ ](https://git-scm.com/docs/git-branch/2.13.7)
  53. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git-branch/2.12.5)
  54. 2.10.5 → 2.11.4 no changes
  55. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-branch/2.9.5)
  56. 2.8.6 no changes
  57. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git-branch/2.7.6)
  58. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git-branch/2.6.7)
  59. 2.5.6 no changes
  60. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git-branch/2.4.12)
  61. 2.1.4 → 2.3.10 no changes
  62. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git-branch/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git-branch#_name)NAME
git-branch - List, create, or delete branches
##  [](https://git-scm.com/docs/git-branch#_synopsis)SYNOPSIS
```
git branch [--color[=_<when>_] | --no-color] [--show-current]
	   [-v [--abbrev=_<n>_ | --no-abbrev]]
	   [--column[=_<options>_] | --no-column] [--sort=_<key>_]
	   [--merged [_<commit>_]] [--no-merged [_<commit>_]]
	   [--contains [_<commit>_]] [--no-contains [_<commit>_]]
	   [--points-at _<object>_] [--format=_<format>_]
	   [(-r|--remotes) | (-a|--all)]
	   [--list] [_<pattern>_…​]
git branch [--track[=(direct|inherit)] | --no-track] [-f]
	   [--recurse-submodules] _<branch-name>_ [_<start-point>_]
git branch (--set-upstream-to=_<upstream>_|-u _<upstream>_) [_<branch-name>_]
git branch --unset-upstream [_<branch-name>_]
git branch (-m|-M) [_<old-branch>_] _<new-branch>_
git branch (-c|-C) [_<old-branch>_] _<new-branch>_
git branch (-d|-D) [-r] _<branch-name>_…​
git branch --edit-description [_<branch-name>_]
```

##  [](https://git-scm.com/docs/git-branch#_description)DESCRIPTION
If `--list` is given, or if there are no non-option arguments, existing branches are listed; the current branch will be highlighted in green and marked with an asterisk. Any branches checked out in linked worktrees will be highlighted in cyan and marked with a plus sign. Option `-r` causes the remote-tracking branches to be listed, and option `-a` shows both local and remote branches.
If a _< pattern>_ is given, it is used as a shell wildcard to restrict the output to matching branches. If multiple patterns are given, a branch is shown if it matches any of the patterns.
Note that when providing a _< pattern>_, you must use `--list`; otherwise the command may be interpreted as branch creation.
With `--contains`, shows only the branches that contain the named commit (in other words, the branches whose tip commits are descendants of the named commit), `--no-contains` inverts it. With `--merged`, only branches merged into the named commit (i.e. the branches whose tip commits are reachable from the named commit) will be listed. With `--no-merged` only branches not merged into the named commit will be listed. If the _< commit>_ argument is missing it defaults to `HEAD` (i.e. the tip of the current branch).
The command’s second form creates a new branch head named _< branch-name>_ which points to the current `HEAD`, or _< start-point>_ if given. As a special case, for _< start-point>_, you may use _< rev-A>_`...`_< rev-B>_ as a shortcut for the merge base of _< rev-A>_ and _< rev-B>_ if there is exactly one merge base. You can leave out at most one of _< rev-A>_ and _< rev-B>_, in which case it defaults to `HEAD`.
Note that this will create the new branch, but it will not switch the working tree to it; use `git` `switch` _< new-branch>_ to switch to the new branch.
When a local branch is started off a remote-tracking branch, Git sets up the branch (specifically the `branch.`_< name>_`.remote` and `branch.`_< name>_`.merge` configuration entries) so that `git` `pull` will appropriately merge from the remote-tracking branch. This behavior may be changed via the global `branch.autoSetupMerge` configuration flag. That setting can be overridden by using the `--track` and `--no-track` options, and changed later using `git` `branch` `--set-upstream-to`.
With a `-m` or `-M` option, _< old-branch>_ will be renamed to _< new-branch>_. If _< old-branch>_ had a corresponding reflog, it is renamed to match _< new-branch>_, and a reflog entry is created to remember the branch renaming. If _< new-branch>_ exists, `-M` must be used to force the rename to happen.
The `-c` and `-C` options have the exact same semantics as `-m` and `-M`, except instead of the branch being renamed, it will be copied to a new name, along with its config and reflog.
With a `-d` or `-D` option, _< branch-name>_ will be deleted. You may specify more than one branch for deletion. If the branch currently has a reflog then the reflog will also be deleted.
Use `-r` together with `-d` to delete remote-tracking branches. Note, that it only makes sense to delete remote-tracking branches if they no longer exist in the remote repository or if `git` `fetch` was configured not to fetch them again. See also the `prune` subcommand of [git-remote[1]](https://git-scm.com/docs/git-remote) for a way to clean up all obsolete remote-tracking branches.
##  [](https://git-scm.com/docs/git-branch#_options)OPTIONS

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--d)`-d`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---delete)`--delete`

Delete a branch. The branch must be fully merged in its upstream branch, or in `HEAD` if no upstream was set with `--track` or `--set-upstream-to`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--D)`-D`

Shortcut for `--delete` `--force`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---create-reflog)`--create-reflog`

Create the branch’s reflog. This activates recording of all changes made to the branch ref, enabling use of date based sha1 expressions such as _< branch-name>_`@{yesterday}`. Note that in non-bare repositories, reflogs are usually enabled by default by the `core.logAllRefUpdates` config option. The negated form `--no-create-reflog` only overrides an earlier `--create-reflog`, but currently does not negate the setting of `core.logAllRefUpdates`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--f)`-f`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---force)`--force`

Reset _< branch-name>_ to _< start-point>_, even if _< branch-name>_ exists already. Without `-f`, `git` `branch` refuses to change an existing branch. In combination with `-d` (or `--delete`), allow deleting the branch irrespective of its merged status, or whether it even points to a valid commit. In combination with `-m` (or `--move`), allow renaming the branch even if the new branch name already exists, the same applies for `-c` (or `--copy`).
Note that `git` `branch` `-f` _< branch-name>_ [_< start-point>_], even with `-f`, refuses to change an existing branch _< branch-name>_ that is checked out in another worktree linked to the same repository.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--m)`-m`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---move)`--move`

Move/rename a branch, together with its config and reflog.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--M)`-M`

Shortcut for `--move` `--force`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--c)`-c`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---copy)`--copy`

Copy a branch, together with its config and reflog.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--C)`-C`

Shortcut for `--copy` `--force`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---colorwhen)`--color`[`=`_< when>_]

Color branches to highlight current, local, and remote-tracking branches. The value must be `always` (the default), `never`, or `auto`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---no-color)`--no-color`

Turn off branch colors, even when the configuration file gives the default to color output. Same as `--color=never`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--i)`-i`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---ignore-case)`--ignore-case`

Sorting and filtering branches are case insensitive.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---omit-empty)`--omit-empty`

Do not print a newline after formatted refs where the format expands to the empty string.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---columnoptions)`--column`[`=`_< options>_]


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---no-column)`--no-column`

Display branch listing in columns. See configuration variable `column.branch` for option syntax. `--column` and `--no-column` without options are equivalent to `always` and `never` respectively.
This option is only applicable in non-verbose mode.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---sortkey)`--sort=`_< key>_

Sort based on _< key>_. Prefix `-` to sort in descending order of the value. You may use the `--sort=`_< key>_ option multiple times, in which case the last key becomes the primary key. The keys supported are the same as those in [git-for-each-ref[1]](https://git-scm.com/docs/git-for-each-ref). Sort order defaults to the value configured for the `branch.sort` variable if it exists, or to sorting based on the full refname (including `refs/...` prefix). This lists detached `HEAD` (if present) first, then local branches and finally remote-tracking branches. See [git-config[1]](https://git-scm.com/docs/git-config).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--r)`-r`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---remotes)`--remotes`

List or delete (if used with `-d`) the remote-tracking branches. Combine with `--list` to match the optional pattern(s).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--a)`-a`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---all)`--all`

List both remote-tracking branches and local branches. Combine with `--list` to match optional pattern(s).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--l)`-l`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---list)`--list`

List branches. With optional _< pattern>_..., e.g. `git` `branch` `--list` `maint-*'`, list only the branches that match the pattern(s).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---show-current)`--show-current`

Print the name of the current branch. In detached `HEAD` state, nothing is printed.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--v)`-v`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--vv)`-vv`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---verbose)`--verbose`

When in list mode, show sha1 and commit subject line for each head, along with relationship to upstream branch (if any). If given twice, print the path of the linked worktree (if any) and the name of the upstream branch, as well (see also `git` `remote` `show` _< remote>_). Note that the current worktree’s `HEAD` will not have its path printed (it will always be your current directory).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--q)`-q`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---quiet)`--quiet`

Be more quiet when creating or deleting a branch, suppressing non-error messages.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---abbrevn)`--abbrev=`_< n>_

In the verbose listing that show the commit object name, show the shortest prefix that is at least _< n>_ hexdigits long that uniquely refers the object. The default value is 7 and can be overridden by the `core.abbrev` config option.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---no-abbrev)`--no-abbrev`

Display the full sha1s in the output listing rather than abbreviating them.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--t)`-t`


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---trackdirectinherit)`--track`[`=`(`direct`|`inherit`)]

When creating a new branch, set up `branch.`_< name>_`.remote` and `branch.`_< name>_`.merge` configuration entries to set "upstream" tracking configuration for the new branch. This configuration will tell git to show the relationship between the two branches in `git` `status` and `git` `branch` `-v`. Furthermore, it directs `git` `pull` without arguments to pull from the upstream when the new branch is checked out.
The exact upstream branch is chosen depending on the optional argument: `-t`, `--track`, or `--track=direct` means to use the start-point branch itself as the upstream; `--track=inherit` means to copy the upstream configuration of the start-point branch.
The `branch.autoSetupMerge` configuration variable specifies how `git` `switch`, `git` `checkout` and `git` `branch` should behave when neither `--track` nor `--no-track` are specified:
The default option, `true`, behaves as though `--track=direct` were given whenever the start-point is a remote-tracking branch. `false` behaves as if `--no-track` were given. `always` behaves as though `--track=direct` were given. `inherit` behaves as though `--track=inherit` were given. `simple` behaves as though `--track=direct` were given only when the _< start-point>_ is a remote-tracking branch and the new branch has the same name as the remote branch.
See [git-pull[1]](https://git-scm.com/docs/git-pull) and [git-config[1]](https://git-scm.com/docs/git-config) for additional discussion on how the `branch.`_< name>_`.remote` and `branch.`_< name>_`.merge` options are used.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---no-track)`--no-track`

Do not set up "upstream" configuration, even if the `branch.autoSetupMerge` configuration variable is set.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---recurse-submodules)`--recurse-submodules`

THIS OPTION IS EXPERIMENTAL! Cause the current command to recurse into submodules if `submodule.propagateBranches` is enabled. See `submodule.propagateBranches` in [git-config[1]](https://git-scm.com/docs/git-config). Currently, only branch creation is supported.
When used in branch creation, a new branch _< branch-name>_ will be created in the superproject and all of the submodules in the superproject’s _< start-point>_. In submodules, the branch will point to the submodule commit in the superproject’s _< start-point>_ but the branch’s tracking information will be set up based on the submodule’s branches and remotes e.g. `git` `branch` `--recurse-submodules` `topic` `origin/main` will create the submodule branch "topic" that points to the submodule commit in the superproject’s "origin/main", but tracks the submodule’s "origin/main".

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---set-upstream)`--set-upstream`

As this option had confusing syntax, it is no longer supported. Please use `--track` or `--set-upstream-to` instead.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt--uupstream)`-u` _< upstream>_


[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---set-upstream-toupstream)`--set-upstream-to=`_< upstream>_

Set up _< branch-name>_'s tracking information so _< upstream>_ is considered _< branch-name>_'s upstream branch. If no _< branch-name>_ is specified, then it defaults to the current branch.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---unset-upstream)`--unset-upstream`

Remove the upstream information for _< branch-name>_. If no branch is specified it defaults to the current branch.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---edit-description)`--edit-description`

Open an editor and edit the text to explain what the branch is for, to be used by various other commands (e.g. `format-patch`, `request-pull`, and `merge` (if enabled)). Multi-line explanations may be used.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---containscommit)`--contains` [_< commit>_]

Only list branches which contain _< commit>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---no-containscommit)`--no-contains` [_< commit>_]

Only list branches which don’t contain _< commit>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---mergedcommit)`--merged` [_< commit>_]

Only list branches whose tips are reachable from _< commit>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---no-mergedcommit)`--no-merged` [_< commit>_]

Only list branches whose tips are not reachable from _< commit>_ (`HEAD` if not specified). Implies `--list`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---points-atobject)`--points-at` _< object>_

Only list branches of _< object>_.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt---formatformat)`--format` _< format>_

A string that interpolates `%`(`fieldname`) from a branch ref being shown and the object it points at. _< format>_ is the same as that of [git-for-each-ref[1]](https://git-scm.com/docs/git-for-each-ref).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branch-name)_< branch-name>_

The name of the branch to create or delete. The new branch name must pass all checks defined by [git-check-ref-format[1]](https://git-scm.com/docs/git-check-ref-format). Some of these checks may restrict the characters allowed in a branch name.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-start-point)_< start-point>_

The new branch head will point to this commit. It may be given as a branch name, a commit-id, or a tag. If this option is omitted, the current `HEAD` will be used instead.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-old-branch)_< old-branch>_

The name of an existing branch. If this option is omitted, the name of the current branch will be used instead.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-new-branch)_< new-branch>_

The new name for an existing branch. The same restrictions as for _< branch-name>_ apply.
##  [](https://git-scm.com/docs/git-branch#_configuration)CONFIGURATION
`pager.branch` is only respected when listing branches, i.e., when `--list` is used or implied. The default is to use a pager. See [git-config[1]](https://git-scm.com/docs/git-config).
Everything above this line in this section isn’t included from the [git-config[1]](https://git-scm.com/docs/git-config) documentation. The content that follows is the same as what’s found there:

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchautoSetupMerge)`branch.autoSetupMerge`

Tells `git` `branch`, `git` `switch` and `git` `checkout` to set up new branches so that [git-pull[1]](https://git-scm.com/docs/git-pull) will appropriately merge from the starting point branch. Note that even if this option is not set, this behavior can be chosen per-branch using the `--track` and `--no-track` options. This option defaults to `true`. The valid settings are:

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-false)`false`

no automatic setup is done

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-true)`true`

automatic setup is done when the starting point is a remote-tracking branch

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-always)`always`

automatic setup is done when the starting point is either a local branch or remote-tracking branch

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-inherit)`inherit`

if the starting point has a tracking configuration, it is copied to the new branch

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-simple)`simple`

automatic setup is done only when the starting point is a remote-tracking branch and the new branch has the same name as the remote branch.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchautoSetupRebase)`branch.autoSetupRebase`

When a new branch is created with `git` `branch`, `git` `switch` or `git` `checkout` that tracks another branch, this variable tells Git to set up pull to rebase instead of merge (see `branch.`_< name>_`.rebase`). The valid settings are:

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-never)`never`

rebase is never automatically set to true.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-local)`local`

rebase is set to true for tracked branches of other local branches.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-remote)`remote`

rebase is set to true for tracked branches of remote-tracking branches.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-always-1)`always`

rebase will be set to true for all tracking branches.
See `branch.autoSetupMerge` for details on how to set up a branch to track another branch. This option defaults to `never`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchsort)`branch.sort`

This variable controls the sort ordering of branches when displayed by [git-branch[1]](https://git-scm.com/docs/git-branch). Without the `--sort=`_< value>_ option provided, the value of this variable will be used as the default. See [git-for-each-ref[1]](https://git-scm.com/docs/git-for-each-ref) field names for valid values.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchnameremote)`branch.`_< name>_`.remote`

When on branch _< name>_, it tells `git` `fetch` and `git` `push` which remote to fetch from or push to. The remote to push to may be overridden with `remote.pushDefault` (for all branches). The remote to push to, for the current branch, may be further overridden by `branch.`_< name>_`.pushRemote`. If no remote is configured, or if you are not on any branch and there is more than one remote defined in the repository, it defaults to `origin` for fetching and `remote.pushDefault` for pushing. Additionally, `.` (a period) is the current local repository (a dot-repository), see `branch.`_< name>_`.merge`'s final note below.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchnamepushRemote)`branch.`_< name>_`.pushRemote`

When on branch _< name>_, it overrides `branch.`_< name>_`.remote` for pushing. It also overrides `remote.pushDefault` for pushing from branch _< name>_. When you pull from one place (e.g. your upstream) and push to another place (e.g. your own publishing repository), you would want to set `remote.pushDefault` to specify the remote to push to for all branches, and use this option to override it for a specific branch.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchnamemerge)`branch.`_< name>_`.merge`

Defines, together with `branch.`_< name>_`.remote`, the upstream branch for the given branch. It tells `git` `fetch`/`git` `pull`/`git` `rebase` which branch to merge and can also affect `git` `push` (see `push.default`). When in branch _< name>_, it tells `git` `fetch` the default refspec to be marked for merging in `FETCH_HEAD`. The value is handled like the remote part of a refspec, and must match a ref which is fetched from the remote given by `branch.`_< name>_`.remote`. The merge information is used by `git` `pull` (which first calls `git` `fetch`) to lookup the default branch for merging. Without this option, `git` `pull` defaults to merge the first refspec fetched. Specify multiple values to get an octopus merge. If you wish to setup `git` `pull` so that it merges into _< name>_ from another branch in the local repository, you can point `branch.`_< name>_`.merge` to the desired branch, and use the relative path setting `.` (a period) for `branch.`_< name>_`.remote`.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchnamemergeOptions)`branch.`_< name>_`.mergeOptions`

Sets default options for merging into branch _< name>_. The syntax and supported options are the same as those of [git-merge[1]](https://git-scm.com/docs/git-merge), but option values containing whitespace characters are currently not supported.

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchnamerebase)`branch.`_< name>_`.rebase`

When true, rebase the branch _< name>_ on top of the fetched branch, instead of merging the default branch from the default remote when `git` `pull` is run. See `pull.rebase` for doing this in a non branch-specific manner.
When `merges` (or just `m`), pass the `--rebase-merges` option to `git` `rebase` so that the local merge commits are included in the rebase (see [git-rebase[1]](https://git-scm.com/docs/git-rebase) for details).
When the value is `interactive` (or just `i`), the rebase is run in interactive mode.
**NOTE** : this is a possibly dangerous operation; do **not** use it unless you understand the implications (see [git-rebase[1]](https://git-scm.com/docs/git-rebase) for details).

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-branchnamedescription)`branch.`_< name>_`.description`

Branch description, can be edited with `git` `branch` `--edit-description`. Branch description is automatically added to the `format-patch` cover letter or `request-pull` summary.
##  [](https://git-scm.com/docs/git-branch#_examples)EXAMPLES

[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-Startdevelopmentfromaknowntag)Start development from a known tag

```
$ git clone git://git.kernel.org/pub/scm/.../linux-2.6 my2.6
$ cd my2.6
$ git branch my2.6.14 v2.6.14   **(1)**
$ git switch my2.6.14
```

  1. This step and the next one could be combined into a single step with "checkout -b my2.6.14 v2.6.14".



[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-Deleteanunneededbranch)Delete an unneeded branch

```
$ git clone git://git.kernel.org/.../git.git my.git
$ cd my.git
$ git branch -d -r origin/todo origin/html origin/man   **(1)**
$ git branch -D test                                    **(2)**
```

  1. Delete the remote-tracking branches "todo", "html" and "man". The next `git` `fetch` or `git` `pull` will create them again unless you configure them not to. See [git-fetch[1]](https://git-scm.com/docs/git-fetch).
  2. Delete the "test" branch even if the "master" branch (or whichever branch is currently checked out) does not have all commits from the test branch.



[](https://git-scm.com/docs/git-branch#Documentation/git-branch.txt-Listingbranchesfromaspecificremote)Listing branches from a specific remote

```
$ git branch -r -l '<remote>/<pattern>'                 **(1)**
$ git for-each-ref 'refs/remotes/<remote>/<pattern>'    **(2)**
```

  1. Using `-a` would conflate _< remote>_ with any local branches you happen to have been prefixed with the same _< remote>_ pattern.
  2. `for-each-ref` can take a wide range of options. See [git-for-each-ref[1]](https://git-scm.com/docs/git-for-each-ref)


Patterns will normally need quoting.
##  [](https://git-scm.com/docs/git-branch#_notes)NOTES
If you are creating a branch that you want to switch to immediately, it is easier to use the `git` `switch` command with its `-c` option to do the same thing with a single command.
The options `--contains`, `--no-contains`, `--merged` and `--no-merged` serve four related but different purposes:
  * `--contains` _< commit>_ is used to find all branches which will need special attention if _< commit>_ were to be rebased or amended, since those branches contain the specified _< commit>_.
  * `--no-contains` _< commit>_ is the inverse of that, i.e. branches that don’t contain the specified _< commit>_.
  * `--merged` is used to find all branches which can be safely deleted, since those branches are fully contained by `HEAD`.
  * `--no-merged` is used to find branches which are candidates for merging into `HEAD`, since those branches are not fully contained by `HEAD`.


When combining multiple `--contains` and `--no-contains` filters, only references that contain at least one of the `--contains` commits and contain none of the `--no-contains` commits are shown.
When combining multiple `--merged` and `--no-merged` filters, only references that are reachable from at least one of the `--merged` commits and from none of the `--no-merged` commits are shown.
##  [](https://git-scm.com/docs/git-branch#_see_also)SEE ALSO
[git-check-ref-format[1]](https://git-scm.com/docs/git-check-ref-format), [git-fetch[1]](https://git-scm.com/docs/git-fetch), [git-remote[1]](https://git-scm.com/docs/git-remote), ["Understanding history: What is a branch?"](https://git-scm.com/docs/user-manual#what-is-a-branch) in the Git User’s Manual.
##  [](https://git-scm.com/docs/git-branch#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### branch
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
